@@ -6,6 +6,7 @@
     Authenticate users in your Flask app with GitHub.
 
 """
+import logging
 from urllib import urlencode
 from urlparse import parse_qs
 from functools import wraps
@@ -13,8 +14,13 @@ from functools import wraps
 import requests
 from flask import redirect, request, json
 
+__version__ = '0.3.0'
+
+logger = logging.getLogger(__name__)
+
 
 class GitHubError(Exception):
+    """Raised if a request fails to the GitHub API."""
 
     def __str__(self):
         response = self.args[0]
@@ -65,6 +71,7 @@ class GitHub(object):
         Redirect to GitHub and request access to a user's data.
 
         """
+        logger.debug("Called authorize()")
         params = {
             'client_id': self.client_id,
             'redirect_uri': self.callback_url,
@@ -73,6 +80,7 @@ class GitHub(object):
             params['scope'] = scope
 
         url = self.BASE_AUTH_URL + 'authorize?' + urlencode(params)
+        logger.debug("Redirecting to %s", url)
         return redirect(url)
 
     def authorized_handler(self, f):
@@ -85,13 +93,13 @@ class GitHub(object):
         @wraps(f)
         def decorated(*args, **kwargs):
             if 'code' in request.args:
-                data = self.handle_response()
+                data = self._handle_response()
             else:
-                data = self.handle_invalid_response()
+                data = self._handle_invalid_response()
             return f(*((data,) + args), **kwargs)
         return decorated
 
-    def handle_response(self):
+    def _handle_response(self):
         """
         Handles response after the redirect to GitHub. This response
         determines if the user has allowed the this application access. If we
@@ -99,25 +107,30 @@ class GitHub(object):
         authenticate requests to GitHub.
 
         """
+        logger.debug("Handling response from GitHub")
         params = {
             'code': request.args.get('code'),
             'client_id': self.client_id,
             'client_secret': self.client_secret
         }
         url = self.BASE_AUTH_URL + 'access_token'
-        response = self.session.post(url, params)
+        logger.debug("POSTing to %s", url)
+        logger.debug(params)
+        response = self.session.post(url, data=params)
         data = parse_qs(response.content)
+        logger.debug("response.content = %s", data)
         for k, v in data.items():
             if len(v) == 1:
                 data[k] = v[0]
-        return data
+        return data.get('access_token', None)
 
-    def handle_invalid_response(self):
+    def _handle_invalid_response(self):
         pass
 
     def raw_request(self, method, resource, params=None, **kwargs):
         """
-        Makes a HTTP request and returns the raw response.
+        Makes a HTTP request and returns the raw
+        :class:`~requests.Response` object.
 
         """
         if params is None:
@@ -131,6 +144,14 @@ class GitHub(object):
             method, url, params=params, allow_redirects=True, **kwargs)
 
     def request(self, method, resource, **kwargs):
+        """
+        Makes a request to the given endpoint.
+        Keyword arguments are passed to the :meth:`~requests.request` method.
+        If the content type of the response is JSON, it will be decoded
+        automatically and a dictionary will be returned.
+        Otherwise the :class:`~requests.Response` object is returned.
+
+        """
         response = self.raw_request(method, resource, **kwargs)
 
         status_code = str(response.status_code)
@@ -146,9 +167,13 @@ class GitHub(object):
             return response
 
     def get(self, resource, **kwargs):
+        """Shortcut for ``request('GET', resource)``."""
         return self.request('GET', resource, **kwargs)
 
     def post(self, resource, data, **kwargs):
+        """Shortcut for ``request('POST', resource)``.
+        Use this to make POST request since it will also encode ``data`` to
+        'application/x-www-form-urlencoded' format."""
         headers = {'Content-Type': 'application/x-www-form-urlencoded'}
         data = json.dumps(data)
         return self.request('POST', resource, headers=headers,
